#ifndef _SENSUS_
#define _SENSUS_

/* ---- Base and digits of hexadecimal numbers ---- */
#define HEXBASE 16
static char digits[] = "0123456789ABCDEF?";

/* ---- Constants for Sensus data-dump ---- */
#define PREHANDSHAKE            2  /* Size of the charakters in "OK"                   */
#define HANDSHAKEDATASIZE      10  /* Size of the handshake-data block                 */
#define HANDSHAKESIZE (PREHANDSHAKE + HANDSHAKEDATASIZE)
#define PREHEADERSIZE           4  /* Number of the characters in "DATA"               */
#define POSTHEADERSIZE          3  /* Number of the characters in "END"                */
#define CHECKSUMSIZE            2  /* Two bytes of checksum                            */
#define DIVEHEADERSIZE          7  /* Size of dive-data header                         */
#define DIVEDATASIZE        32768  /* 2^16 bytes profile                               */
#define PROFILESIZE (DIVEDATASIZE + PREHEADERSIZE + POSTHEADERSIZE + CHECKSUMSIZE) 
#define MAXRETRY               10  /* Number of retries when Sensus is contacted       */
#define BLOCKSIZE            1024  /* Read this number of bytes in one block           */
#define BATTOK                 16  /* Battery ok == 16, Battery low == 64              */
#define TIMESIZE                8  /* Number of bytes used to represent sys-time       */
#define MAGICHEADER   (char) 0xFF  /* Header at the beginning of dive data             */ 
#define MAGICTAIL     (char) 0xFE  /* Header for dive data ends with this marker       */
#define TIMEENDMARKER (char) 0xFE  /* The dump-time ends with this marker              */
#define SHALLOWDEPTH (int)(13 + 3) /* Depth + 13 (ft) indicating possible end of dive  */
#define SHALLOWCNT       (int) 17  /* Number of shallow samples indicating end of dive */

/* ---- A macro for safely reading all profile samples with wrap-around ---- */
#define WRAP(index) ((((index) - (PREHEADERSIZE)) % DIVEDATASIZE) + PREHEADERSIZE)
#define WRAPOFF(index, offset) (((((index) + offset) - (PREHEADERSIZE))\
                                 % DIVEDATASIZE) + PREHEADERSIZE)
#endif
